import java.awt.*;
import java.io.*;
import java.util.*;

/** 
 * Configuration.java
 * Configuration handler
 * @version 1.0   10/1/97 
 * @author Byeongseob Ki
 */

public class Configuration {

  /** 
   * parsed config values
   */
  public CPlane config1d;
  public Config2D config2d;
  public Config3D config3d;

  private String sv_menu = null;
  private String sv_set = null;
  private String browser_name = null;
  private String filter_home = null;
  private boolean globalCheck = false;
  
  public Configuration(String setting) {

    if (setting != null) {
       if (!setting.endsWith(File.separator))
         setting = setting + File.separator;
 
       sv_menu = setting + "sv_menu";
       sv_set = setting + "sv_set.cfg";
    }

    config1d = new CPlane();
    config2d = new Config2D();
    config3d = new Config3D();

    if (setting != null) 
       parseConfigs(sv_set);
  }

  /**
   * return menu file name
   */
  public String getMenuFile() {
     return sv_menu;
  }

  /*
   * return setting file name
   */
  public String getConfigFile() {
     return sv_set;
  }
  
  /**
   * return browser name
   */
  public String getBrowserName() {
     return browser_name;
  }

  
  /**
   * return filer home directory
   */
  public String getFilterHome() {
     return filter_home;
  }

  /**
   * return global check flag
   */
  public boolean isGlobalMode() {
     return globalCheck;
  }

  /**
   * reconfiguration 
   */ 
   public void reconfigure() {
      parseConfigs(sv_set);
   }  
  
  // parse configuration file
  private void parseConfigs(String fname) {

     String s;

     try {
       FileInputStream propFile = new FileInputStream(fname);
       Properties p = new Properties(System.getProperties());
       p.load(propFile);

       browser_name = p.getProperty("brwoser_name");
       filter_home = p.getProperty("filter_home_directory");

       s = p.getProperty("command_broadcast");
       if (s != null && s.equals("yes"))  globalCheck = true;
       else                  globalCheck = false;

       //////////////////////////////////////////////////////////
       // 1d
       //////////////////////////////////////////////////////////
       s = p.getProperty("connect_points_1d");
       if (s != null && s.equals("yes"))  config1d.connect_point = true;
       else                  config1d.connect_point = false;

       s = p.getProperty("color_by_amr_1d");
       if (s != null && s.equals("yes"))  config1d.amr = true;
       else                  config1d.amr = false; 

       s = p.getProperty("color_by_info_1d");
       if (s != null && s.equals("yes"))  config1d.color_by_info = true;
       else                  config1d.color_by_info = false;

       s = p.getProperty("color_by_set_1d");
       if (s != null && s.equals("yes"))  config1d.color_by_set = true;
       else                  config1d.color_by_set = false;

       s = p.getProperty("tickmark_1d");
       if (s != null && s.equals("yes"))  config1d.tickmark = true;
       else                  config1d.tickmark = false;

       s = p.getProperty("display_label_1d");
       if (s != null && s.equals("yes"))  config1d.display_label = true;
       else                  config1d.display_label = false;

       s = p.getProperty("display_legend_1d");
       if (s != null && s.equals("yes"))  config1d.display_legend = true;
       else                  config1d.display_legend = false;

       s = p.getProperty("colormap_1d");
       if (s != null) config1d.colormap = s.trim();

       s = p.getProperty("x_label_1d");
       if (s != null)  config1d.xLabel = s.trim();

       s = p.getProperty("y_label_1d");
       if (s != null)  config1d.yLabel = s.trim();

       s = p.getProperty("x_label_rotate_1d");
       if (s != null && s.equals("yes")) config1d.isXLabelRotate = true;

       s = p.getProperty("y_label_rotate_1d");
       if (s != null && s.equals("yes")) config1d.isYLabelRotate = true;

       s = p.getProperty("global_mode_1d");
       if (s != null && s.equals("yes"))  config1d.global_mode = true;
       else                  config1d.global_mode = false;

       s = p.getProperty("overlay_mode_1d");
       if (s != null && s.equals("yes"))  config1d.overlay_mode = true;
       else                  config1d.overlay_mode = false;

       s = p.getProperty("discard_mode_1d");
       if (s != null && s.equals("yes"))  config1d.discard_mode = true;
       else                  config1d.discard_mode = false;

       s = p.getProperty("display_time_1d");
       if (s != null && s.equals("yes"))  config1d.display_time = true;
       else                  config1d.display_time = false;

       String sr = p.getProperty("bgColor_1d_red");
       String sg = p.getProperty("bgColor_1d_green");
       String sb = p.getProperty("bgColor_1d_blue");

       if (sr != null && sg != null && sb != null) {
          try {
             Color bg = new Color(Integer.valueOf(sr).intValue(),
                                  Integer.valueOf(sr).intValue(),
                                  Integer.valueOf(sr).intValue());
             if (bg != null) config1d.bgColor = bg;
          } catch (Exception e) {
             System.out.println("Color is not valid.");
          }
       }


       //////////////////////////////////////////////////////////
       // 2d
       //////////////////////////////////////////////////////////
       s = p.getProperty("plot_mode_2d");
       if (s != null) config2d.plotmode_2d = Integer.valueOf(s).intValue();

       s = p.getProperty("delay_regenerating_2d");
       if (s != null && s.equals("yes"))  config2d.delay_regenerating_2d = true;
       else                  config2d.delay_regenerating_2d = false;

       s = p.getProperty("bounding_box_2d");
       if (s != null && s.equals("yes"))  config2d.bounding_box_2d = true;
       else                  config2d.bounding_box_2d = false;

       s = p.getProperty("xymesh_2d");
       if (s != null && s.equals("yes"))  config2d.xymesh_2d = true;
       else                  config2d.xymesh_2d = false;

       s = p.getProperty("xyticks_2d");
       if (s != null && s.equals("yes"))  config2d.xyticks_2d = true;
       else                  config2d.xyticks_2d = false;

       s = p.getProperty("zticks_2d");
       if (s != null && s.equals("yes"))  config2d.zticks_2d = true;
       else                  config2d.zticks_2d = false;

       s = p.getProperty("display_grid_2d");
       if (s != null && s.equals("yes"))  config2d.display_grid_2d = true;
       else                  config2d.display_grid_2d = false;

       s = p.getProperty("vector_plot_2d");
       if (s != null && s.equals("yes"))  config2d.vector_plot_2d = true;
       else                  config2d.vector_plot_2d = false;

       s = p.getProperty("x_label_2d");
       if (s != null)  config2d.xLabel = s.trim();

       s = p.getProperty("y_label_2d");
       if (s != null)  config2d.yLabel = s.trim();

       s = p.getProperty("z_label_2d");
       if (s != null)  config2d.zLabel = s.trim();
    
       s = p.getProperty("colormap_2d");
       if (s != null)  config2d.colormap_2d = s.trim();
////////////////////////////////////////////////////////////////
// TEMPARARY
////////////////////////////////////////////////////////////////
       if (s != null)  config3d.colormap = s.trim();

       s = p.getProperty("global_mode_2d");
       if (s != null && s.equals("yes"))  config2d.global_mode = true;
       else                  config2d.global_mode = false;

       s = p.getProperty("overlay_mode_2d");
       if (s != null && s.equals("yes"))  config2d.overlay_mode = true;
       else                  config2d.overlay_mode = false;

       s = p.getProperty("discard_mode_2d");
       if (s != null && s.equals("yes"))  config2d.discard_mode = true;
       else                  config2d.discard_mode = false;

       s = p.getProperty("display_time_2d");
       if (s != null && s.equals("yes"))  config2d.display_time = true;
       else                  config2d.display_time = false;

       sr = p.getProperty("bgColor_2d_red");
       sg = p.getProperty("bgColor_2d_green");
       sb = p.getProperty("bgColor_2d_blue");

       if (sr != null && sg != null && sb != null) {
          try {
             Color bg = new Color(Integer.valueOf(sr).intValue(),
                                  Integer.valueOf(sr).intValue(),
                                  Integer.valueOf(sr).intValue());
             if (bg != null) config2d.bgColor = bg;
          } catch (Exception e) {
             System.out.println("Color is not valid.");
          }
       }
 
     } catch (Exception e) {
e.printStackTrace();
       System.err.println("I/O failed while reading the configuration file...");
     }
  }


}  // end of class

